@@ -1,7 +1,6 @@
 /* GNU m4 -- A simple macro processor
 
-   Copyright (C) 1989, 1990, 1991, 1992, 1993, 1994, 2004, 2005, 2006,
-   2007, 2008, 2009 Free Software Foundation, Inc.
+   Copyright (C) 1989-1994, 2004-2011 Free Software Foundation, Inc.
 
    This file is part of GNU M4.
 
@@ -25,6 +24,7 @@
 #include <sys/stat.h>
 
 #include "gl_avltree_oset.h"
+#include "gl_xoset.h"
 
 /* Size of initial in-memory buffer size for diversions.  Small diversions
    would usually fit in.  */
@@ -58,13 +58,13 @@ struct m4_diversion
   {
     union
       {
-	FILE *file;		/* Diversion file on disk.  */
-	char *buffer;		/* Malloc'd diversion buffer.  */
-	m4_diversion *next;	/* Free-list pointer */
+        FILE *file;             /* Diversion file on disk.  */
+        char *buffer;           /* Malloc'd diversion buffer.  */
+        m4_diversion *next;     /* Free-list pointer */
       } u;
-    int divnum;			/* Which diversion this represents.  */
-    int size;			/* Usable size before reallocation.  */
-    int used;			/* Used buffer length, or tmp file exists.  */
+    int divnum;                 /* Which diversion this represents.  */
+    int size;                   /* Usable size before reallocation.  */
+    int used;                   /* Used buffer length, or tmp file exists.  */
   };
 
 /* Table of diversions 1 through INT_MAX.  */
@@ -162,16 +162,16 @@ cleanup_tmpfile (void)
       const void *elt;
       gl_oset_iterator_t iter = gl_oset_iterator (diversion_table);
       while (gl_oset_iterator_next (&iter, &elt))
-	{
-	  m4_diversion *diversion = (m4_diversion *) elt;
-	  if (!diversion->size && diversion->u.file
-	      && close_stream_temp (diversion->u.file) != 0)
-	    {
-	      M4ERROR ((0, errno,
-			"cannot clean temporary file for diversion"));
-	      fail = true;
-	    }
-	}
+        {
+          m4_diversion *diversion = (m4_diversion *) elt;
+          if (!diversion->size && diversion->u.file
+              && close_stream_temp (diversion->u.file) != 0)
+            {
+              M4ERROR ((0, errno,
+                        "cannot clean temporary file for diversion"));
+              fail = true;
+            }
+        }
       gl_oset_iterator_free (&iter);
     }
 
@@ -191,7 +191,8 @@ m4_tmpname (int divnum)
   if (buffer == NULL)
     {
       tail = xasprintf ("%s/m4-%d", output_temp_dir->dir_name, INT_MAX);
-      buffer = obstack_copy0 (&diversion_storage, tail, strlen (tail));
+      buffer = (char *) obstack_copy0 (&diversion_storage, tail,
+                                       strlen (tail));
       free (tail);
       tail = strrchr (buffer, '-') + 1;
     }
@@ -217,8 +218,8 @@ m4_tmpfile (int divnum)
     {
       output_temp_dir = create_temp_dir ("m4-", NULL, true);
       if (output_temp_dir == NULL)
-	M4ERROR ((EXIT_FAILURE, errno,
-		  "cannot create temporary file for diversion"));
+        M4ERROR ((EXIT_FAILURE, errno,
+                  "cannot create temporary file for diversion"));
       atexit (cleanup_tmpfile);
     }
   name = m4_tmpname (divnum);
@@ -228,11 +229,11 @@ m4_tmpfile (int divnum)
     {
       unregister_temp_file (output_temp_dir, name);
       M4ERROR ((EXIT_FAILURE, errno,
-		"cannot create temporary file for diversion"));
+                "cannot create temporary file for diversion"));
     }
   else if (set_cloexec_flag (fileno (file), true) != 0)
     M4ERROR ((warning_status, errno,
-	      "Warning: cannot protect diversion across forks"));
+              "Warning: cannot protect diversion across forks"));
   return file;
 }
 
@@ -250,16 +251,16 @@ m4_tmpopen (int divnum, bool reread)
   if (tmp_file1_owner == divnum)
     {
       if (reread && fseeko (tmp_file1, 0, SEEK_SET) != 0)
-	m4_error (EXIT_FAILURE, errno,
-		  _("cannot seek within diversion"));
+        m4_error (EXIT_FAILURE, errno,
+                  _("cannot seek within diversion"));
       tmp_file2_recent = false;
       return tmp_file1;
     }
   else if (tmp_file2_owner == divnum)
     {
       if (reread && fseeko (tmp_file2, 0, SEEK_SET) != 0)
-	m4_error (EXIT_FAILURE, errno,
-		  _("cannot seek within diversion"));
+        m4_error (EXIT_FAILURE, errno,
+                  _("cannot seek within diversion"));
       tmp_file2_recent = true;
       return tmp_file2;
     }
@@ -268,14 +269,14 @@ m4_tmpopen (int divnum, bool reread)
   file = fopen_temp (name, O_BINARY ? "rb+" : "r+");
   if (file == NULL)
     M4ERROR ((EXIT_FAILURE, errno,
-	      "cannot create temporary file for diversion"));
+              "cannot create temporary file for diversion"));
   else if (set_cloexec_flag (fileno (file), true) != 0)
     m4_error (0, errno, _("cannot protect diversion across forks"));
   /* Update mode starts at the beginning of the stream, but sometimes
      we want the end.  */
   else if (!reread && fseeko (file, 0, SEEK_END) != 0)
     m4_error (EXIT_FAILURE, errno,
-	      _("cannot seek within diversion"));
+              _("cannot seek within diversion"));
   return file;
 }
 
@@ -291,19 +292,19 @@ m4_tmpclose (FILE *file, int divnum)
   if (divnum != tmp_file1_owner && divnum != tmp_file2_owner)
     {
       if (tmp_file2_recent)
-	{
-	  if (tmp_file1_owner)
-	    result = close_stream_temp (tmp_file1);
-	  tmp_file1 = file;
-	  tmp_file1_owner = divnum;
-	}
+        {
+          if (tmp_file1_owner)
+            result = close_stream_temp (tmp_file1);
+          tmp_file1 = file;
+          tmp_file1_owner = divnum;
+        }
       else
-	{
-	  if (tmp_file2_owner)
-	    result = close_stream_temp (tmp_file2);
-	  tmp_file2 = file;
-	  tmp_file2_owner = divnum;
-	}
+        {
+          if (tmp_file2_owner)
+            result = close_stream_temp (tmp_file2);
+          tmp_file2 = file;
+          tmp_file2_owner = divnum;
+        }
     }
   return result;
 }
@@ -316,14 +317,14 @@ m4_tmpremove (int divnum)
     {
       int result = close_stream_temp (tmp_file1);
       if (result)
-	return result;
+        return result;
       tmp_file1_owner = 0;
     }
   else if (divnum == tmp_file2_owner)
     {
       int result = close_stream_temp (tmp_file2);
       if (result)
-	return result;
+        return result;
       tmp_file2_owner = 0;
     }
   return cleanup_temp_file (output_temp_dir, m4_tmpname (divnum));
@@ -343,33 +344,33 @@ m4_tmprename (int oldnum, int newnum)
     {
       /* Be careful of mingw, which can't rename an open file.  */
       if (RENAME_OPEN_FILE_WORKS)
-	tmp_file1_owner = newnum;
+        tmp_file1_owner = newnum;
       else
-	{
-	  if (close_stream_temp (tmp_file1))
-	    m4_error (EXIT_FAILURE, errno,
-		      _("cannot close temporary file for diversion"));
-	  tmp_file1_owner = 0;
-	}
+        {
+          if (close_stream_temp (tmp_file1))
+            m4_error (EXIT_FAILURE, errno,
+                      _("cannot close temporary file for diversion"));
+          tmp_file1_owner = 0;
+        }
     }
   else if (oldnum == tmp_file2_owner)
     {
       /* Be careful of mingw, which can't rename an open file.  */
       if (RENAME_OPEN_FILE_WORKS)
-	tmp_file2_owner = newnum;
+        tmp_file2_owner = newnum;
       else
-	{
-	  if (close_stream_temp (tmp_file2))
-	    m4_error (EXIT_FAILURE, errno,
-		      _("cannot close temporary file for diversion"));
-	  tmp_file2_owner = 0;
-	}
+        {
+          if (close_stream_temp (tmp_file2))
+            m4_error (EXIT_FAILURE, errno,
+                      _("cannot close temporary file for diversion"));
+          tmp_file2_owner = 0;
+        }
     }
   /* Either it is safe to rename an open file, or no one should have
      oldname open at this point.  */
   if (rename (oldname, newname))
     m4_error (EXIT_FAILURE, errno,
-	      _("cannot create temporary file for diversion"));
+              _("cannot create temporary file for diversion"));
   unregister_temp_file (output_temp_dir, oldname);
   free (oldname);
   return m4_tmpopen (newnum, false);
@@ -384,7 +385,7 @@ void
 output_init (void)
 {
   diversion_table = gl_oset_create_empty (GL_AVLTREE_OSET, cmp_diversion_CB,
-					  NULL);
+                                          NULL);
   div0.u.file = stdout;
   output_diversion = &div0;
   output_file = stdout;
@@ -406,14 +407,15 @@ output_exit (void)
   obstack_free (&diversion_storage, NULL);
 }
 
-/*-----------------------------------------------------------------------.
-| Reorganize in-memory diversion buffers so the current diversion can	 |
-| accomodate LENGTH more characters without further reorganization.  The |
-| current diversion buffer is made bigger if possible.  But to make room |
-| for a bigger buffer, one of the in-memory diversion buffers might have |
-| to be flushed to a newly created temporary file.  This flushed buffer	 |
-| might well be the current one.					 |
-`-----------------------------------------------------------------------*/
+/*----------------------------------------------------------------.
+| Reorganize in-memory diversion buffers so the current diversion |
+| can accomodate LENGTH more characters without further           |
+| reorganization.  The current diversion buffer is made bigger if |
+| possible.  But to make room for a bigger buffer, one of the     |
+| in-memory diversion buffers might have to be flushed to a newly |
+| created temporary file.  This flushed buffer might well be the  |
+| current one.                                                    |
+`----------------------------------------------------------------*/
 
 static void
 make_room_for (int length)
@@ -445,30 +447,30 @@ make_room_for (int length)
       const void *elt;
 
       /* Find out the buffer having most data, in view of flushing it to
-	 disk.  Fake the current buffer as having already received the
-	 projected data, while making the selection.  So, if it is
-	 selected indeed, we will flush it smaller, before it grows.  */
+         disk.  Fake the current buffer as having already received the
+         projected data, while making the selection.  So, if it is
+         selected indeed, we will flush it smaller, before it grows.  */
 
       selected_diversion = output_diversion;
       selected_used = output_diversion->used + length;
 
       iter = gl_oset_iterator (diversion_table);
       while (gl_oset_iterator_next (&iter, &elt))
-	{
-	  diversion = (m4_diversion *) elt;
-	  if (diversion->used > selected_used)
-	    {
-	      selected_diversion = diversion;
-	      selected_used = diversion->used;
-	    }
-	}
+        {
+          diversion = (m4_diversion *) elt;
+          if (diversion->used > selected_used)
+            {
+              selected_diversion = diversion;
+              selected_used = diversion->used;
+            }
+        }
       gl_oset_iterator_free (&iter);
 
       /* Create a temporary file, write the in-memory buffer of the
-	 diversion to this file, then release the buffer.  Zero the
-	 diversion before doing anything that can exit () (including
-	 m4_tmpfile), so that the atexit handler doesn't try to close
-	 a garbage pointer as a file.  */
+         diversion to this file, then release the buffer.  Zero the
+         diversion before doing anything that can exit () (including
+         m4_tmpfile), so that the atexit handler doesn't try to close
+         a garbage pointer as a file.  */
 
       selected_buffer = selected_diversion->u.buffer;
       total_buffer_size -= selected_diversion->size;
@@ -477,13 +479,13 @@ make_room_for (int length)
       selected_diversion->u.file = m4_tmpfile (selected_diversion->divnum);
 
       if (selected_diversion->used > 0)
-	{
-	  count = fwrite (selected_buffer, (size_t) selected_diversion->used,
-			  1, selected_diversion->u.file);
-	  if (count != 1)
-	    M4ERROR ((EXIT_FAILURE, errno,
-		      "ERROR: cannot flush diversion to temporary file"));
-	}
+        {
+          count = fwrite (selected_buffer, (size_t) selected_diversion->used,
+                          1, selected_diversion->u.file);
+          if (count != 1)
+            M4ERROR ((EXIT_FAILURE, errno,
+                      "ERROR: cannot flush diversion to temporary file"));
+        }
 
       /* Reclaim the buffer space for other diversions.  */
 
@@ -505,20 +507,20 @@ make_room_for (int length)
     {
       /* Close any selected file since it is not the current diversion.  */
       if (selected_diversion)
-	{
-	  FILE *file = selected_diversion->u.file;
-	  selected_diversion->u.file = NULL;
-	  if (m4_tmpclose (file, selected_diversion->divnum) != 0)
-	    m4_error (0, errno,
-		      _("cannot close temporary file for diversion"));
-	}
+        {
+          FILE *file = selected_diversion->u.file;
+          selected_diversion->u.file = NULL;
+          if (m4_tmpclose (file, selected_diversion->divnum) != 0)
+            m4_error (0, errno,
+                      _("cannot close temporary file for diversion"));
+        }
 
       /* The current buffer may be safely reallocated.  */
       {
-	char *buffer = output_diversion->u.buffer;
-	output_diversion->u.buffer = xcharalloc ((size_t) wanted_size);
-	memcpy (output_diversion->u.buffer, buffer, output_diversion->used);
-	free (buffer);
+        char *buffer = output_diversion->u.buffer;
+        output_diversion->u.buffer = xcharalloc ((size_t) wanted_size);
+        memcpy (output_diversion->u.buffer, buffer, output_diversion->used);
+        free (buffer);
       }
 
       total_buffer_size += wanted_size - output_diversion->size;
@@ -529,17 +531,17 @@ make_room_for (int length)
     }
 }
 
-/*------------------------------------------------------------------------.
-| Output one character CHAR, when it is known that it goes to a diversion |
-| file or an in-memory diversion buffer.				  |
-`------------------------------------------------------------------------*/
+/*--------------------------------------------------------------.
+| Output one character CHAR, when it is known that it goes to a |
+| diversion file or an in-memory diversion buffer.              |
+`--------------------------------------------------------------*/
 
 #define OUTPUT_CHARACTER(Char) \
-  if (output_file)							\
-    putc ((Char), output_file);						\
-  else if (output_unused == 0)						\
-    output_character_helper ((Char));					\
-  else									\
+  if (output_file)                                                      \
+    putc ((Char), output_file);                                         \
+  else if (output_unused == 0)                                          \
+    output_character_helper ((Char));                                   \
+  else                                                                  \
     (output_unused--, *output_cursor++ = (Char))
 
 static void
@@ -556,10 +558,10 @@ output_character_helper (int character)
     }
 }
 
-/*------------------------------------------------------------------------.
-| Output one TEXT having LENGTH characters, when it is known that it goes |
-| to a diversion file or an in-memory diversion buffer.			  |
-`------------------------------------------------------------------------*/
+/*-------------------------------------------------------------------.
+| Output one TEXT having LENGTH characters, when it is known that it |
+| goes to a diversion file or an in-memory diversion buffer.         |
+`-------------------------------------------------------------------*/
 
 void
 output_text (const char *text, int length)
@@ -576,7 +578,7 @@ output_text (const char *text, int length)
     {
       count = fwrite (text, length, 1, output_file);
       if (count != 1)
-	M4ERROR ((EXIT_FAILURE, errno, "ERROR: copying inserted file"));
+        M4ERROR ((EXIT_FAILURE, errno, "ERROR: copying inserted file"));
     }
   else
     {
@@ -626,7 +628,7 @@ shipout_text (struct obstack *obs, const char *text, int length, int line)
     switch (length)
       {
 
-	/* In-line short texts.  */
+        /* In-line short texts.  */
 
       case 8: OUTPUT_CHARACTER (*text); text++;
       case 7: OUTPUT_CHARACTER (*text); text++;
@@ -637,80 +639,80 @@ shipout_text (struct obstack *obs, const char *text, int length, int line)
       case 2: OUTPUT_CHARACTER (*text); text++;
       case 1: OUTPUT_CHARACTER (*text);
       case 0:
-	return;
+        return;
 
-	/* Optimize longer texts.  */
+        /* Optimize longer texts.  */
 
       default:
-	output_text (text, length);
+        output_text (text, length);
       }
   else
     {
       /* Check for syncline only at the start of a token.  Multiline
-	 tokens, and tokens that are out of sync but in the middle of
-	 the line, must wait until the next raw newline triggers a
-	 syncline.  */
+         tokens, and tokens that are out of sync but in the middle of
+         the line, must wait until the next raw newline triggers a
+         syncline.  */
       if (start_of_output_line)
-	{
-	  start_of_output_line = false;
-	  output_current_line++;
+        {
+          start_of_output_line = false;
+          output_current_line++;
 #ifdef DEBUG_OUTPUT
-	  xfprintf (stderr, "DEBUG: line %d, cur %d, cur out %d\n",
-		   line, current_line, output_current_line);
+          xfprintf (stderr, "DEBUG: line %d, cur %d, cur out %d\n",
+                   line, current_line, output_current_line);
 #endif
 
-	  /* Output a `#line NUM' synchronization directive if needed.
-	     If output_current_line was previously given a negative
-	     value (invalidated), output `#line NUM "FILE"' instead.  */
+          /* Output a `#line NUM' synchronization directive if needed.
+             If output_current_line was previously given a negative
+             value (invalidated), output `#line NUM "FILE"' instead.  */
 
-	  if (output_current_line != line)
-	    {
-	      OUTPUT_CHARACTER ('#');
-	      OUTPUT_CHARACTER ('l');
-	      OUTPUT_CHARACTER ('i');
-	      OUTPUT_CHARACTER ('n');
-	      OUTPUT_CHARACTER ('e');
-	      OUTPUT_CHARACTER (' ');
-	      for (cursor = ntoa (line, 10); *cursor; cursor++)
-		OUTPUT_CHARACTER (*cursor);
-	      if (output_current_line < 1 && current_file[0] != '\0')
-		{
-		  OUTPUT_CHARACTER (' ');
-		  OUTPUT_CHARACTER ('"');
-		  for (cursor = current_file; *cursor; cursor++)
-		    OUTPUT_CHARACTER (*cursor);
-		  OUTPUT_CHARACTER ('"');
-		}
-	      OUTPUT_CHARACTER ('\n');
-	      output_current_line = line;
-	    }
-	}
+          if (output_current_line != line)
+            {
+              OUTPUT_CHARACTER ('#');
+              OUTPUT_CHARACTER ('l');
+              OUTPUT_CHARACTER ('i');
+              OUTPUT_CHARACTER ('n');
+              OUTPUT_CHARACTER ('e');
+              OUTPUT_CHARACTER (' ');
+              for (cursor = ntoa (line, 10); *cursor; cursor++)
+                OUTPUT_CHARACTER (*cursor);
+              if (output_current_line < 1 && current_file[0] != '\0')
+                {
+                  OUTPUT_CHARACTER (' ');
+                  OUTPUT_CHARACTER ('"');
+                  for (cursor = current_file; *cursor; cursor++)
+                    OUTPUT_CHARACTER (*cursor);
+                  OUTPUT_CHARACTER ('"');
+                }
+              OUTPUT_CHARACTER ('\n');
+              output_current_line = line;
+            }
+        }
 
       /* Output the token, and track embedded newlines.  */
       for (; length-- > 0; text++)
-	{
-	  if (start_of_output_line)
-	    {
-	      start_of_output_line = false;
-	      output_current_line++;
+        {
+          if (start_of_output_line)
+            {
+              start_of_output_line = false;
+              output_current_line++;
 #ifdef DEBUG_OUTPUT
-	      xfprintf (stderr, "DEBUG: line %d, cur %d, cur out %d\n",
-		       line, current_line, output_current_line);
+              xfprintf (stderr, "DEBUG: line %d, cur %d, cur out %d\n",
+                       line, current_line, output_current_line);
 #endif
-	    }
-	  OUTPUT_CHARACTER (*text);
-	  if (*text == '\n')
-	    start_of_output_line = true;
-	}
+            }
+          OUTPUT_CHARACTER (*text);
+          if (*text == '\n')
+            start_of_output_line = true;
+        }
     }
 }
 
 /* Functions for use by diversions.  */
 
-/*--------------------------------------------------------------------------.
-| Make a file for diversion DIVNUM, and install it in the diversion table.  |
-| Grow the size of the diversion table as needed.			    |
-`--------------------------------------------------------------------------*/
+/*------------------------------------------------------------------.
+| Make a file for diversion DIVNUM, and install it in the diversion |
+| table.  Grow the size of the diversion table as needed.           |
+`------------------------------------------------------------------*/
 
 /* The number of possible diversions is limited only by memory and
    available file descriptors (each overflowing diversion uses one).  */
@@ -726,23 +728,23 @@ make_diversion (int divnum)
   if (output_diversion)
     {
       if (!output_diversion->size && !output_diversion->u.file)
-	{
-	  assert (!output_diversion->used);
-	  if (!gl_oset_remove (diversion_table, output_diversion))
-	    error (EXIT_FAILURE, 0, "INTERNAL ERROR: make_diversion failed");
-	  output_diversion->u.next = free_list;
-	  free_list = output_diversion;
-	}
+        {
+          assert (!output_diversion->used);
+          if (!gl_oset_remove (diversion_table, output_diversion))
+            assert (false);
+          output_diversion->u.next = free_list;
+          free_list = output_diversion;
+        }
       else if (output_diversion->size)
-	output_diversion->used = output_diversion->size - output_unused;
+        output_diversion->used = output_diversion->size - output_unused;
       else if (output_diversion->used)
-	{
-	  FILE *file = output_diversion->u.file;
-	  output_diversion->u.file = NULL;
-	  if (m4_tmpclose (file, output_diversion->divnum) != 0)
-	    m4_error (0, errno,
-		      _("cannot close temporary file for diversion"));
-	}
+        {
+          FILE *file = output_diversion->u.file;
+          output_diversion->u.file = NULL;
+          if (m4_tmpclose (file, output_diversion->divnum) != 0)
+            m4_error (0, errno,
+                      _("cannot close temporary file for diversion"));
+        }
       output_diversion = NULL;
       output_file = NULL;
       output_cursor = NULL;
@@ -760,28 +762,28 @@ make_diversion (int divnum)
     {
       const void *elt;
       if (gl_oset_search_atleast (diversion_table, threshold_diversion_CB,
-				  &divnum, &elt))
-	{
-	  m4_diversion *temp = (m4_diversion *) elt;
-	  if (temp->divnum == divnum)
-	    diversion = temp;
-	}
+                                  &divnum, &elt))
+        {
+          m4_diversion *temp = (m4_diversion *) elt;
+          if (temp->divnum == divnum)
+            diversion = temp;
+        }
     }
   if (diversion == NULL)
     {
       /* First time visiting this diversion.  */
       if (free_list)
-	{
-	  diversion = free_list;
-	  free_list = diversion->u.next;
-	}
+        {
+          diversion = free_list;
+          free_list = diversion->u.next;
+        }
       else
-	{
-	  diversion = (m4_diversion *) obstack_alloc (&diversion_storage,
-						      sizeof *diversion);
-	  diversion->size = 0;
-	  diversion->used = 0;
-	}
+        {
+          diversion = (m4_diversion *) obstack_alloc (&diversion_storage,
+                                                      sizeof *diversion);
+          diversion->size = 0;
+          diversion->used = 0;
+        }
       diversion->u.file = NULL;
       diversion->divnum = divnum;
       gl_oset_add (diversion_table, diversion);
@@ -796,8 +798,8 @@ make_diversion (int divnum)
   else
     {
       if (!output_diversion->u.file && output_diversion->used)
-	output_diversion->u.file = m4_tmpopen (output_diversion->divnum,
-					       false);
+        output_diversion->u.file = m4_tmpopen (output_diversion->divnum,
+                                               false);
       output_file = output_diversion->u.file;
     }
   output_current_line = -1;
@@ -806,7 +808,7 @@ make_diversion (int divnum)
 /*-------------------------------------------------------------------.
 | Insert a FILE into the current output file, in the same manner     |
 | diversions are handled.  This allows files to be included, without |
-| having them rescanned by m4.					     |
+| having them rescanned by m4.                                       |
 `-------------------------------------------------------------------*/
 
 void
@@ -824,9 +826,9 @@ insert_file (FILE *file)
     {
       length = fread (buffer, 1, sizeof buffer, file);
       if (ferror (file))
-	M4ERROR ((EXIT_FAILURE, errno, "error reading inserted file"));
+        M4ERROR ((EXIT_FAILURE, errno, "error reading inserted file"));
       if (length == 0)
-	break;
+        break;
       output_text (buffer, length);
     }
 }
@@ -835,7 +837,7 @@ insert_file (FILE *file)
 | Insert DIVERSION (but not div0) into the current output file.  The |
 | diversion is NOT placed on the expansion obstack, because it must  |
 | not be rescanned.  When the file is closed, it is deleted by the   |
-| system.							     |
+| system.                                                            |
 `-------------------------------------------------------------------*/
 
 static void
@@ -845,47 +847,47 @@ insert_diversion_helper (m4_diversion *diversion)
   if (output_diversion)
     {
       if (diversion->size)
-	{
-	  if (!output_diversion->u.file)
-	    {
-	      /* Transferring diversion metadata is faster than
-		 copying contents.  */
-	      assert (!output_diversion->used && output_diversion != &div0
-		      && !output_file);
-	      output_diversion->u.buffer = diversion->u.buffer;
-	      output_diversion->size = diversion->size;
-	      output_cursor = diversion->u.buffer + diversion->used;
-	      output_unused = diversion->size - diversion->used;
-	      diversion->u.buffer = NULL;
-	    }
-	  else
-	    {
-	      /* Avoid double-charging the total in-memory size when
-		 transferring from one in-memory diversion to
-		 another.  */
-	      total_buffer_size -= diversion->size;
-	      output_text (diversion->u.buffer, diversion->used);
-	    }
-	}
+        {
+          if (!output_diversion->u.file)
+            {
+              /* Transferring diversion metadata is faster than
+                 copying contents.  */
+              assert (!output_diversion->used && output_diversion != &div0
+                      && !output_file);
+              output_diversion->u.buffer = diversion->u.buffer;
+              output_diversion->size = diversion->size;
+              output_cursor = diversion->u.buffer + diversion->used;
+              output_unused = diversion->size - diversion->used;
+              diversion->u.buffer = NULL;
+            }
+          else
+            {
+              /* Avoid double-charging the total in-memory size when
+                 transferring from one in-memory diversion to
+                 another.  */
+              total_buffer_size -= diversion->size;
+              output_text (diversion->u.buffer, diversion->used);
+            }
+        }
       else if (!output_diversion->u.file)
-	{
-	  /* Transferring diversion metadata is faster than copying
-	     contents.  */
-	  assert (!output_diversion->used && output_diversion != &div0
-		  && !output_file);
-	  output_diversion->u.file = m4_tmprename (diversion->divnum,
-						   output_diversion->divnum);
-	  output_diversion->used = 1;
-	  output_file = output_diversion->u.file;
-	  diversion->u.file = NULL;
-	  diversion->size = 1;
-	}
+        {
+          /* Transferring diversion metadata is faster than copying
+             contents.  */
+          assert (!output_diversion->used && output_diversion != &div0
+                  && !output_file);
+          output_diversion->u.file = m4_tmprename (diversion->divnum,
+                                                   output_diversion->divnum);
+          output_diversion->used = 1;
+          output_file = output_diversion->u.file;
+          diversion->u.file = NULL;
+          diversion->size = 1;
+        }
       else
-	{
-	  if (!diversion->u.file)
-	    diversion->u.file = m4_tmpopen (diversion->divnum, true);
-	  insert_file (diversion->u.file);
-	}
+        {
+          if (!diversion->u.file)
+            diversion->u.file = m4_tmpopen (diversion->divnum, true);
+          insert_file (diversion->u.file);
+        }
 
       output_current_line = -1;
     }
@@ -894,22 +896,22 @@ insert_diversion_helper (m4_diversion *diversion)
   if (diversion->size)
     {
       if (!output_diversion)
-	total_buffer_size -= diversion->size;
+        total_buffer_size -= diversion->size;
       free (diversion->u.buffer);
       diversion->size = 0;
     }
   else
     {
       if (diversion->u.file)
-	{
-	  FILE *file = diversion->u.file;
-	  diversion->u.file = NULL;
-	  if (m4_tmpclose (file, diversion->divnum) != 0)
-	    m4_error (0, errno,
-		      _("cannot clean temporary file for diversion"));
-	}
+        {
+          FILE *file = diversion->u.file;
+          diversion->u.file = NULL;
+          if (m4_tmpclose (file, diversion->divnum) != 0)
+            m4_error (0, errno,
+                      _("cannot clean temporary file for diversion"));
+        }
       if (m4_tmpremove (diversion->divnum) != 0)
-	M4ERROR ((0, errno, "cannot clean temporary file for diversion"));
+        M4ERROR ((0, errno, "cannot clean temporary file for diversion"));
     }
   diversion->used = 0;
   gl_oset_remove (diversion_table, diversion);
@@ -917,11 +919,12 @@ insert_diversion_helper (m4_diversion *diversion)
   free_list = diversion;
 }
 
-/*-------------------------------------------------------------------------.
-| Insert diversion number DIVNUM into the current output file.  The	   |
-| diversion is NOT placed on the expansion obstack, because it must not be |
-| rescanned.  When the file is closed, it is deleted by the system.	   |
-`-------------------------------------------------------------------------*/
+/*------------------------------------------------------------------.
+| Insert diversion number DIVNUM into the current output file.  The |
+| diversion is NOT placed on the expansion obstack, because it must |
+| not be rescanned.  When the file is closed, it is deleted by the  |
+| system.                                                           |
+`------------------------------------------------------------------*/
 
 void
 insert_diversion (int divnum)
@@ -933,18 +936,18 @@ insert_diversion (int divnum)
   if (divnum <= 0 || current_diversion == divnum)
     return;
   if (gl_oset_search_atleast (diversion_table, threshold_diversion_CB,
-			      &divnum, &elt))
+                              &divnum, &elt))
     {
       m4_diversion *diversion = (m4_diversion *) elt;
       if (diversion->divnum == divnum)
-	insert_diversion_helper (diversion);
+        insert_diversion_helper (diversion);
     }
 }
 
-/*-------------------------------------------------------------------------.
-| Get back all diversions.  This is done just before exiting from main (), |
-| and from m4_undivert (), if called without arguments.			   |
-`-------------------------------------------------------------------------*/
+/*----------------------------------------------------------------.
+| Get back all diversions.  This is done just before exiting from |
+| main, and from m4_undivert (), if called without arguments.     |
+`----------------------------------------------------------------*/
 
 void
 undivert_all (void)
@@ -955,7 +958,7 @@ undivert_all (void)
     {
       m4_diversion *diversion = (m4_diversion *) elt;
       if (diversion->divnum != current_diversion)
-	insert_diversion_helper (diversion);
+        insert_diversion_helper (diversion);
     }
   gl_oset_iterator_free (&iter);
 }
@@ -975,34 +978,35 @@ freeze_diversions (FILE *file)
   saved_number = current_diversion;
   last_inserted = 0;
   make_diversion (0);
-  output_file = file;		/* kludge in the frozen file */
+  output_file = file; /* kludge in the frozen file */
 
   iter = gl_oset_iterator (diversion_table);
   while (gl_oset_iterator_next (&iter, &elt))
     {
       m4_diversion *diversion = (m4_diversion *) elt;
       if (diversion->size || diversion->used)
-	{
-	  if (diversion->size)
-	    xfprintf (file, "D%d,%d\n", diversion->divnum, diversion->used);
-	  else
-	    {
-	      struct stat file_stat;
-	      diversion->u.file = m4_tmpopen (diversion->divnum, true);
-	      if (fstat (fileno (diversion->u.file), &file_stat) < 0)
-		M4ERROR ((EXIT_FAILURE, errno, "cannot stat diversion"));
-	      if (file_stat.st_size < 0
-		  || file_stat.st_size != (unsigned long int) file_stat.st_size)
-		M4ERROR ((EXIT_FAILURE, 0, "diversion too large"));
-	      xfprintf (file, "D%d,%lu\n", diversion->divnum,
-			(unsigned long int) file_stat.st_size);
-	    }
+        {
+          if (diversion->size)
+            xfprintf (file, "D%d,%d\n", diversion->divnum, diversion->used);
+          else
+            {
+              struct stat file_stat;
+              diversion->u.file = m4_tmpopen (diversion->divnum, true);
+              if (fstat (fileno (diversion->u.file), &file_stat) < 0)
+                M4ERROR ((EXIT_FAILURE, errno, "cannot stat diversion"));
+              if (file_stat.st_size < 0
+                  || (file_stat.st_size + 0UL
+                      != (unsigned long int) file_stat.st_size))
+                M4ERROR ((EXIT_FAILURE, 0, "diversion too large"));
+              xfprintf (file, "D%d,%lu\n", diversion->divnum,
+                        (unsigned long int) file_stat.st_size);
+            }
 
-	  insert_diversion_helper (diversion);
-	  putc ('\n', file);
+          insert_diversion_helper (diversion);
+          putc ('\n', file);
 
-	  last_inserted = diversion->divnum;
-	}
+          last_inserted = diversion->divnum;
+        }
     }
   gl_oset_iterator_free (&iter);
 
